Skip to contents

A query operation for specifying a result axis in a query sequence. This is typically the first operation in a query sequence and determines which axis the query will operate on. It sets the context for subsequent operations in the query. See the Julia documentation for details.

Usage

Axis(value = NULL, ...)

Arguments

value

Optional string specifying the axis name (NULL for unspecified)

...

Additional arguments needed to support usage of pipe operator

Value

A query operation object that can be used in a query sequence