Skip to contents

Start specifying a mask to apply to an axis of the result. Must be accompanied by an EndMask. See the Julia documentation for details.

Usage

BeginMask(value, ...)

Arguments

value

String specifying the property name for the initial mask

...

Additional arguments needed to support usage of pipe operator

Value

A query operation object