Skip to contents

Start specifying a negated mask to apply to an axis of the result. Must be accompanied by an EndMask. See the Julia documentation for details.

Usage

BeginNegatedMask(value, ...)

Arguments

value

String specifying the property name for the initial negated mask

...

Additional arguments needed to support usage of pipe operator

Value

A query operation object