Skip to contents

Finish specifying a mask to apply to an axis, following BeginMask or BeginNegatedMask. See the Julia documentation for details.

Usage

EndMask(...)

Arguments

...

Additional arguments needed to support usage of pipe operator

Value

A query operation object