Skip to contents

Specify value per matrix column to group the columns by. Must be followed by a ReduceToColumn to reduce each group of columns to a single column. See the Julia documentation for details.

Usage

GroupColumnsBy(value, ...)

Arguments

value

String specifying the property to group columns by

...

Additional arguments needed to support usage of pipe operator

Value

A query operation object