Skip to contents

Specify value per matrix row to group the rows by. Must be followed by a ReduceToRow to reduce each group of rows to a single row. See the Julia documentation for details.

Usage

GroupRowsBy(value, ...)

Arguments

value

String specifying the property to group rows by

...

Additional arguments needed to support usage of pipe operator

Value

A query operation object