Builds a :: (optionally :: <name>) query fragment, looking up
the named matrix property indexed by the prior two axes.
Value
A DafrQuery.
Builds a :: (optionally :: <name>) query fragment, looking up
the named matrix property indexed by the prior two axes.
A DafrQuery.