Skip to contents

A query operation for looking up a set of names in a Daf object. This operation retrieves the entry names of the current axis. See the Julia documentation for details.

Usage

Names(...)

Arguments

...

Additional arguments needed to support usage of pipe operator

Value

A query operation object that can be used in a query sequence