Skip to contents

Specify a reduction operation to convert each column of a matrix to a single value, reducing the matrix to a single row. See the Julia documentation for details.

Usage

ReduceToRow(reduction, ...)

Arguments

reduction

A reduction operation (e.g., from Mean(), Sum(), etc.) or a string describing the reduction

...

Additional arguments needed to support usage of pipe operator

Value

A query operation object