Skip to contents

Builds a % Significant <params> query fragment. Zeroes entries whose absolute value is below high, optionally preserving entries between low and high when any entry in the group is above high.

Usage

Significant(type = NULL, ...)

Arguments

type

Optional output type (character scalar) or a piped DafrQuery.

...

Named parameters such as high, low; or a piped DafrQuery.

Value

A DafrQuery.

See also

Examples

Significant(high = 3)
#> <DafrQuery> % Significant high: 3 
Significant(high = 3, low = 2)
#> <DafrQuery> % Significant high: 3 low: 2