Skip to contents

Used when the mask matrix is square and we'd like to use a column as a mask. See the Julia documentation for details.

Usage

SquareMaskColumn(value, ...)

SquareColumnIs(value, ...)

Arguments

value

String specifying the value

...

Additional arguments needed to support usage of pipe operator

Value

A query operation object

Functions

  • SquareMaskColumn(): Deprecated: use SquareColumnIs() instead.