R/deprecated.R
R/query.R
SquareRowIs.Rd
Used when the mask matrix is square and we'd like to use a row as a mask. See the Julia documentation for details.
SquareMaskRow(value, ...) SquareRowIs(value, ...)
String specifying the value
Additional arguments needed to support usage of pipe operator
A query operation object
SquareMaskRow(): Deprecated: use SquareRowIs() instead.
SquareMaskRow()
SquareRowIs()