Escapes special characters in a value so it can be safely embedded in a query string. This is needed when values contain characters that have special meaning in the query syntax (e.g., spaces, quotes, backslashes).
Details
See the Julia documentation for details.