Test whether a query yields an axis entry vector.
Arguments
- query_string
A query string (character scalar) or a DafrQuery object produced by the query builders (e.g.
Axis("cell") |> LookupVector("donor")).
Test whether a query yields an axis entry vector.
A query string (character scalar) or a
DafrQuery object produced by the query builders (e.g.
Axis("cell") |> LookupVector("donor")).