Each key maps to a regular file under root. Directories are
created as needed. The root must be writable.
Examples
tmp <- tempfile()
s <- new_dir_store(tmp)
Each key maps to a regular file under root. Directories are
created as needed. The root must be writable.
tmp <- tempfile()
s <- new_dir_store(tmp)