Element-wise operation that converts every element to its absolute value. This operation preserves the shape of the data (scalar, vector, or matrix) but changes the values. By default, the output data type is the unsigned version of the input data type. See the Julia documentation for details.