A query operation that treats values in a vector property as names of entries in another axis.
This operation is commonly used with CountBy and GroupBy,
where vector values need to be interpreted as axis entry names. If no axis is specified, values
are treated as entries of a default axis based on context. See the Julia
documentation for
details.