Skip to contents

A query operation providing a default value to use if the data is missing some property. This is useful when querying for properties that might not exist for all entries, allowing you to provide a fallback value instead of getting an error. See the Julia documentation for details.

Usage

IfMissing(default_value, ...)

Arguments

default_value

Value to use when data is missing the property

...

Additional arguments needed to support usage of pipe operator

Value

A query operation object that can be used in a query sequence