A query operation providing a default value to use if the data is missing some property. This is useful when querying for properties that might not exist for all entries, allowing you to provide a fallback value instead of getting an error. See the Julia documentation for details.