R/query.R
LookupMatrix.Rd
A query operation for looking up the value of a matrix property. See the Julia documentation for details.
LookupMatrix(value, ...)
String specifying the matrix property name to look up
Additional arguments needed to support usage of pipe operator
A query operation object that can be used in a query sequence