R/query.R
LookupScalar.Rd
A query operation for looking up the value of a scalar property. See the Julia documentation for details.
LookupScalar(value = NULL, ...)
String specifying the scalar property name to look up
Additional arguments needed to support usage of pipe operator
A query operation object that can be used in a query sequence