Element-wise query operation: keep only "significant" entries.
Source:R/query_builders_exports.R
Significant.RdBuilds a % Significant <params> query fragment. Zeroes entries
whose absolute value is below high, optionally preserving entries
between low and high when any entry in the group is above
high.
Value
A DafrQuery.