R/deprecated.R
R/query.R
SquareColumnIs.Rd
Used when the mask matrix is square and we'd like to use a column as a mask. See the Julia documentation for details.
SquareMaskColumn(value, ...) SquareColumnIs(value, ...)
String specifying the value
Additional arguments needed to support usage of pipe operator
A query operation object
SquareMaskColumn(): Deprecated: use SquareColumnIs() instead.
SquareMaskColumn()
SquareColumnIs()