Copy all content from source to destination
Usage
copy_all(
destination,
source,
empty = NULL,
overwrite = FALSE,
relayout = TRUE,
types = NULL,
insist = TRUE
)Arguments
- destination
A Daf object to copy to
- source
A Daf object to copy from
- empty
A named list mapping data keys to values for filling missing data
- overwrite
Whether to overwrite if data already exists
- relayout
Whether to allow relayout
- types
Optional named list mapping data keys to types for conversion. If NULL, the original types are preserved.
- insist
Whether to fail if data doesn't exist (TRUE by default)
Details
See the Julia documentation for details.