Returns the unique identifier name of the Daf data set.
name() is deprecated in favor of daf_name() to avoid name conflicts with other packages.
Returns the unique identifier name of the Daf data set.
name() is deprecated in favor of daf_name() to avoid name conflicts with other packages.