Retrieves multiple vector properties for an axis as a dataframe, returning the raw
Julia-style result. For a more R-friendly version, see get_dataframe().
Value
A data.frame containing the specified columns for the axis. If columns is NULL, all columns are returned, with an additional column "name" containing the axis entries.
Details
See the Julia documentation for more details.