Test whether a matrix exists for an axis pair.
Arguments
- daf
A
DafReader.- rows_axis
Row-axis name.
- columns_axis
Column-axis name.
- name
Matrix name.
- relayout
If
TRUE(default), also reportTRUEwhen the matrix is stored only at the flipped axis pair(columns_axis, rows_axis). Set toFALSEto ask the strict "this exact layout?" question. Mirrors Juliahas_matrix(...; relayout).
Examples
# Mirrors readers.jl jldoctest at line 748.
has_matrix(example_cells_daf(), "gene", "cell", "UMIs") # TRUE
#> [1] TRUE
# `relayout = FALSE` asks the strict "this exact layout?" question:
has_matrix(example_cells_daf(), "gene", "cell", "UMIs", relayout = FALSE)
#> [1] TRUE